package plugin

import "github.com/docker/cli/cli-plugins/plugin"

Index

Variables

var PersistentPreRunE func(*cobra.Command, []string) error

PersistentPreRunE must be called by any plugin command (or subcommand) which uses the cobra `PersistentPreRun*` hook. Plugins which do not make use of `PersistentPreRun*` do not need to call this (although it remains safe to do so). Plugins are recommended to use `PersistentPreRunE` to enable the error to be returned. Should not be called outside of a command's PersistentPreRunE hook and must not be run unless Run has been called.

Functions

func Run

func Run(makeCmd func(command.Cli) *cobra.Command, meta metadata.Metadata, ops ...command.CLIOption)

Run is the top-level entry point to the CLI plugin framework. It should be called from the plugin's "main()" function. It initializes a new command.DockerCli instance with the given options before calling makeCmd to construct the plugin command, then invokes the plugin command using RunPlugin.

func RunPlugin

func RunPlugin(dockerCli *command.DockerCli, plugin *cobra.Command, meta metadata.Metadata) error

RunPlugin executes the specified plugin command

func RunningStandalone

func RunningStandalone() bool

RunningStandalone tells a CLI plugin it is run standalone by direct execution

Source Files

plugin.go

Version
v29.4.2+incompatible (latest)
Published
Apr 20, 2026
Platform
linux/amd64
Imports
15 packages
Last checked
2 hours ago

Tools for package owners.