package fixtures
import "github.com/docker/cli/e2e/internal/fixtures"
Index ¶
- Constants
- func SetupConfigFile(t *testing.T) fs.Dir
- func WithConfig(dir string) func(cmd *icmd.Cmd)
- func WithHome(path string) func(*icmd.Cmd)
Constants ¶
const ( // AlpineImage is an image in the test registry AlpineImage = "registry:5000/alpine:frozen" // BusyboxImage is an image in the test registry BusyboxImage = "registry:5000/busybox:frozen" )
Functions ¶
func SetupConfigFile ¶
SetupConfigFile creates a config.json file for testing
func WithConfig ¶
WithConfig sets an environment variable for the docker config location
func WithHome ¶
WithHome sets the HOME environment variable
Source Files ¶
- Version
- v29.4.2+incompatible (latest)
- Published
- Apr 20, 2026
- Platform
- linux/amd64
- Imports
- 5 packages
- Last checked
- 9 hours ago –
Tools for package owners.