package api

import "github.com/docker/cli/internal/oauth/api"

Index

Types

type State

type State struct {
	DeviceCode      string `json:"device_code"`
	UserCode        string `json:"user_code"`
	VerificationURI string `json:"verification_uri_complete"`
	ExpiresIn       int    `json:"expires_in"`
	Interval        int    `json:"interval"`
}

State represents the state of exchange after submitting.

func (State) ExpiryDuration

func (s State) ExpiryDuration() time.Duration

ExpiryDuration returns the total duration for which the client should keep polling.

func (State) IntervalDuration

func (s State) IntervalDuration() time.Duration

IntervalDuration returns the duration that should be waited between each auth polling event.

Source Files

state.go

Version
v29.4.2+incompatible (latest)
Published
Apr 20, 2026
Platform
linux/amd64
Imports
1 packages
Last checked
9 hours ago

Tools for package owners.