package testutils
import "github.com/docker/cli/e2e/testutils"
Index ¶
Functions ¶
func SetupPlugin ¶
SetupPlugin builds a plugin and creates a temporary directory with the plugin's config.json and rootfs, which will be removed in [t.Cleanup]. It returns the location of the temporary directory.
Source Files ¶
Directories ¶
| Path | Synopsis |
|---|---|
| e2e/testutils/plugins |
- Version
- v29.4.2+incompatible (latest)
- Published
- Apr 20, 2026
- Platform
- linux/amd64
- Imports
- 14 packages
- Last checked
- 53 minutes ago –
Tools for package owners.